"""Provides access to Bootstrap inspired functionality like `ErrorAlert`, `InfoAlert`,
`WarningAlert`, `Card` and the `extend` function that needs to be run before you start using the
Bootstrap functionality.
"""
from .bootstrap import ErrorAlert, InfoAlert, WarningAlert, extend
from .cards.cards import Card
