"""In this module we define all Resource Tags and exposes them via the TAGS list."""
from awesome_panel.shared.models import Tag

# Please keep the Tags sorted alphabetically
ALTERNATIVE = Tag(name="Alternatives")
APP = Tag("App")
APP_IN_GALLERY = Tag(name="App In Gallery")
ARTICLE = Tag(name="Article")
AWESOME_PANEL_ORG = Tag(name="Awesome-panel.org")
AWESOMEPANEL_EXPRESS = Tag(name="awesome_panel.express")
CODE = Tag("Code")
DEPLOYMENT = Tag(name="Deployment")
INSPIRATION = Tag(name="Inspiration")
FINANCE = Tag(name="Finance")
IMAGE_RECOGNITION = Tag(name="Image Recognition")
MACHINE_LEARNING = Tag(name="Machine Learning")
NLP = Tag(name="NLP")
SOCIAL = Tag(name="Social")
PANEL = Tag(name="Panel")
SISTER_SITES = Tag(name="Sister Sites")
TECHNICAL = Tag(name="Technical")
TUTORIAL = Tag(name="Tutorial")
VIDEO = Tag(name="Video")
VOILA = Tag(name="Voila")
VTK = Tag(name="VTK")

# Please keep this list sorted alphabetically
TAGS = [
    ALTERNATIVE,
    APP,
    APP_IN_GALLERY,
    ARTICLE,
    AWESOMEPANEL_EXPRESS,
    AWESOME_PANEL_ORG,
    CODE,
    DEPLOYMENT,
    INSPIRATION,
    FINANCE,
    IMAGE_RECOGNITION,
    MACHINE_LEARNING,
    NLP,
    SOCIAL,
    PANEL,
    TECHNICAL,
    TUTORIAL,
    VIDEO,
    VOILA,
    VTK,
]
