
/* https://github.com/MarcSkovMadsen/awesome-panel/blob/master/package/awesome_panel/express/templates/bootstrap_dashboard/bootstrap_dashboard.css */
body{
  overflow-x: hidden;
  overflow-y: hidden;
}
img {
    /* we wan't no overflow. Will make it easier to include images in markdown */
    max-width: 100%;
}
table {
    width: 95%;
}

header a:-webkit-any-link {
  color: white;
}

#page {
  display: grid;
  width: 100%;
  height: 100vh;
  grid-template: [header-left] "head head" 60px [header-right]
                 [main-left]   "nav  main" 1fr  [main-right] / 200px 1fr;
}

header {
  grid-area: head;

  color: white;
  background-color: black;

  box-shadow: 5px 5px 20px grey;

  z-index: 1000;

  text-align: center;
  font-size: 1rem;
}
header a:link {
  color: white;
  text-decoration: none;
}
header a:visited {
  color: white;
}
header a:hover{
  color: white;
}
header i.fab, header i.fas {
  font-size: 1rem;
  padding-left: 0.3rem;
}

nav {
  grid-area: nav;
  background-color: rgb(248, 249, 250);
  border-right-color: rgb(230, 230, 230);
  border-right-width: 0.1px;
  border-right-style: solid;
  overflow-x: hidden;
  overflow-y: auto;
}

main {
  grid-area: main;
  overflow-x: hidden;
  overflow-y: scroll;
}

.bk.app-title a{
    color: white;
    background-color: black;
    text-align: center;
    font-size: 1rem;
}
.bk.app-title a:link {
    text-decoration: none;
}
.bk.app-title a:hover{
    color: white;
}
div.bk.navigation div.bk button {
    text-align: left !important;
}