"""In this module we define all Authors of resources or apps in the gallery and exposes
them via the AUTHORS list"""
from awesome_panel.shared.models import Author

# Authors
ANDREW_HUANG = Author(
    name="Andrew Huang",
    url="https://twitter.com/iateandrew1",
    github_url="https://github.com/ahuang11",
    github_avatar_url=(
        "https://avatars3.githubusercontent.com/u/"
        "15331990?s=400&u=6f855e2f82d576fd22110f2ac9b1b7ec4825d916&v=4"
    ),
)
AWESOME_PANEL_ORG = Author(
    name="Awesome-panel.org",
    url="https://awesome-panel.org",
    github_url="https://github.com/marcskovmadsen",
    github_avatar_url="https://avatars0.githubusercontent.com/u/24277277?s=400&v=4",
)
BENJAMIN_COOLEY = Author(
    name="Bokeh",
    url="https://bendoesdata.github.io/",
    github_url="https://github.com/bendoesdata",
    github_avatar_url="https://avatars3.githubusercontent.com/u/8440965",
)
BOKEH = Author(
    name="Bokeh",
    url="https://docs.bokeh.org/en/latest/ ",
    github_url="https://github.com/bokeh",
    github_avatar_url="https://avatars3.githubusercontent.com/u/8440965",
)
DASH = Author(
    name="Dash",
    url="https://plot.ly/dash/",
    github_url="https://github.com/plotly/dash",
    github_avatar_url="https://avatars2.githubusercontent.com/u/5997976",
)
HOLOVIZ = Author(
    name="HoloViz",
    url="http://holoviz.org/",
    github_url="https://github.com/holoviz",
    github_avatar_url="https://avatars2.githubusercontent.com/u/51678735",
)
INFORMATIONISBEUTIFULL = Author(
    name="Information is beautiful",
    url="https://informationisbeautiful.net/",
    github_url="",
    github_avatar_url="",
)
INTAKE = Author(
    name="Intake",
    url="https://github.com/intake",
    github_url="https://github.com/intake",
    github_avatar_url="https://avatars1.githubusercontent.com/u/1469464",
)
JAMES_BEDNAR = Author(
    name="James A. Bednar",
    url="https://github.com/jbednar",
    github_url="https://github.com/jbednar",
    github_avatar_url="https://avatars0.githubusercontent.com/u/1695496",
)
JUSTIN_BOIS = Author(
    name="Justin Bois",
    url="http://bois.caltech.edu/",
    github_url="https://github.com/JUSTIN_BOIS",
    github_avatar_url="https://avatars3.githubusercontent.com/u/1873517",
)
MARC_SKOV_MADSEN = Author(
    name="Marc Skov Madsen",
    url="https://datamodelsanalytics.com",
    github_url="https://github.com/marcskovmadsen",
    github_avatar_url="https://avatars0.githubusercontent.com/u/42288570",
)
OURWORLDINDATA = Author(
    name="Our World in Data",
    url="https://ourworldindata.org/",
    github_url="https://github.com/owid",
    github_avatar_url="https://avatars3.githubusercontent.com/u/14187135",
)
PANEL = Author(
    name="panel",
    url="https://panel.pyviz.org/",
    github_url="https://github.com/holoviz/",
    github_avatar_url="https://avatars2.githubusercontent.com/u/51678735",
)
PHILIPP_RUDIGER = Author(
    name="Philipp Rudiger",
    url="http://philippjfr.com/",
    github_url="https://github.com/philippjfr",
    github_avatar_url="https://avatars0.githubusercontent.com/u/1550771",
)
PLOTLY = Author(
    name="Plotly",
    url="https://plot.ly/",
    github_url="https://github.com/plotly",
    github_avatar_url="https://avatars2.githubusercontent.com/u/5997976",
)
QUANSIGHT = Author(
    name="Quansight",
    url="https://www.quansight.com/",
    github_url="https://github.com/Quansight",
    github_avatar_url="https://avatars1.githubusercontent.com/u/34879953",
)
STREAMLIT = Author(
    name="Streamlit",
    url="https://streamlit.io/",
    github_url="https://github.com/streamlit",
    github_avatar_url="https://avatars1.githubusercontent.com/u/45109972",
)
VOILA = Author(
    name="Voila",
    url="https://github.com/voila-dashboards",
    github_url="https://github.com/voila-dashboards",
    github_avatar_url="https://avatars1.githubusercontent.com/u/55792893?s=200&v=4",
)
DAMIAN_FARRELL = Author(
    name="Damien Farrell",
    url="https://dmnfarrell.github.io/",
    github_url="https://github.com/dmnfarrell",
    github_avatar_url="https://avatars0.githubusercontent.com/u/7859189",
)
XAVARTLEY = Author(
    name="xavArtely",
    url="https://github.com/xavArtley",
    github_url="https://github.com/xavArtley",
    github_avatar_url="https://avatars1.githubusercontent.com/u/18531147",
)

AUTHORS = [
    ANDREW_HUANG,
    AWESOME_PANEL_ORG,
    BOKEH,
    DASH,
    DAMIAN_FARRELL,
    HOLOVIZ,
    INTAKE,
    JAMES_BEDNAR,
    MARC_SKOV_MADSEN,
    OURWORLDINDATA,
    PANEL,
    PHILIPP_RUDIGER,
    QUANSIGHT,
    PLOTLY,
    STREAMLIT,
    VOILA,
    XAVARTLEY,
]
